@@ -5,10 +5,10 @@ use warnings;
 use parent qw(Plack::Middleware);
 use Plack::Util::Accessor qw(renderer);
 use Text::MicroTemplate;
-use Data::Dump;
+use Data::Dumper::Concise;
 use Scalar::Util;
 
-our $VERSION = '0.16';
+our $VERSION = '0.18';
 
 sub call {
     my($self, $env) = @_;
@@ -59,7 +59,7 @@ sub vardump {
     my $scalar = shift;
     return '(undef)' unless defined $scalar;
     return "$scalar" unless ref $scalar;
-    scalar Data::Dump::dump($scalar);
+    return scalar Dumper( $scalar );
 }
 
 sub build_template {
@@ -117,7 +117,7 @@ my $list_template = __PACKAGE__->build_template(<<'EOTMPL');
 % my($key, $value) = splice(@{$_[0]->{list}}, 0, 2);
             <tr class="<%= ++$i % 2 ? 'plDebugOdd' : 'plDebugEven' %>">
                 <td><%= $key %></td>
-                <td><%= vardump($value) %></td>
+                <td><pre><%= vardump($value) %></pre></td>
             </tr>
 % }
     </tbody>
